@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 Brodie Gaslam
+Copyright (C) 2023 Brodie Gaslam
 
 This file is part of "vetr - Trust, but Verify"
 
@@ -188,7 +188,8 @@ size_t CSR_strmlen_x(const char * str, size_t maxlen) {
   if((uintptr_t)str > UINTPTR_MAX - maxlen)
     // nocov start
     error(
-      "Internal error in strmlen, maxlen would imply pointer overflow"
+      "Internal error in strmlen, maxlen (%jd) would imply pointer overflow",
+      maxlen
     );
     // nocov end
 
@@ -323,6 +324,7 @@ char * CSR_smprintf6(
   full_len = CSR_add_szt(full_len, CSR_strmlen_x(d, maxlen));
   full_len = CSR_add_szt(full_len, CSR_strmlen_x(e, maxlen));
   full_len = CSR_add_szt(full_len, CSR_strmlen_x(f, maxlen));
+  full_len = CSR_add_szt(full_len, 1);
 
   char * res;
 
@@ -335,9 +337,11 @@ char * CSR_smprintf6(
   char * e_cpy = CSR_strmcpy(e, maxlen);
   char * f_cpy = CSR_strmcpy(f, maxlen);
 
-  res = R_alloc(full_len + 1, sizeof(char));
-  int res_len = sprintf(
-    res, CSR_strmcpy(format, maxlen), a_cpy, b_cpy, c_cpy, d_cpy, e_cpy, f_cpy
+  res = R_alloc(full_len, sizeof(char));
+  int res_len = snprintf(
+    res, full_len,
+    CSR_strmcpy(format, maxlen),
+    a_cpy, b_cpy, c_cpy, d_cpy, e_cpy, f_cpy
   );
   if(res_len < 0) {
     // nocov start
