@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2022 Brodie Gaslam
+Copyright (C) 2023 Brodie Gaslam
 
 This file is part of "vetr - Trust, but Verify"
 
@@ -262,17 +262,9 @@ static SEXP VALC_error_standard(
         }
         break;
       case -2: {
-        const char * err_tok_tmp = type2char(TYPEOF(eval_tmp));
-        const char * err_tok_base = "is \"%s\" instead of a \"logical\"";
-        err_tok = R_alloc(
-          strlen(err_tok_tmp) + strlen(err_tok_base), sizeof(char)
-        );
-        if(sprintf(err_tok, err_tok_base, err_tok_tmp) < 0)
-          // nocov start
-          error(
-            "Internal error: build token error failure; contact maintainer"
-          );
-          // nocov end
+          const char * err_tok_tmp = type2char(TYPEOF(eval_tmp));
+          const char * err_tok_base = "is \"%s\" instead of a \"logical\"";
+          err_tok = CSR_smprintf1(set.nchar_max, err_tok_base, err_tok_tmp);
         }
         break;
       case -1: err_tok = "FALSE"; break;
@@ -311,7 +303,7 @@ static SEXP VALC_error_standard(
     if(!err_call.multi_line) extra_blank = " ";
 
     for(int i = 0; i < 4; ++i) {
-      if(INT_MAX - str_sizes[i] < alloc_size)
+      if(INT_MAX - str_sizes[i] <= alloc_size)
         // nocov start
         error(
           "%s%s (%d)",
@@ -322,12 +314,13 @@ static SEXP VALC_error_standard(
 
       alloc_size += str_sizes[i];
     }
+    ++alloc_size;  // for terminator; above we check with <=
     err_str = R_alloc(alloc_size, sizeof(char));
 
     // not sure why we're not using cstringr here
     if(
-      sprintf(
-        err_str, err_base, err_call.chr, extra_blank, err_extra, err_tok
+      snprintf(
+        err_str, alloc_size, err_base, err_call.chr, extra_blank, err_extra, err_tok
       ) < 0
     ) {
       // nocov start
@@ -376,7 +369,9 @@ static SEXP VALC_error_extract(
 \* -------------------------------------------------------------------------- */
 /*
 @param lang the validator expression
-@param arg_lang the substituted language being validated
+@param arg_lang the substituted language being validated, which doesn't actually
+  have to be language in cases where a function is called via `do.call`, or a
+  scalar atomic is provided.
 @param arg_tag the variable name being validated
 @param arg_value the value being validated
 @param lang_full solely so that we can produce error message with original call
@@ -390,9 +385,6 @@ SEXP VALC_evaluate(
   SEXP lang, SEXP arg_lang, SEXP arg_tag, SEXP arg_value, SEXP lang_full,
   struct VALC_settings set, int use_lang_raw
 ) {
-  if(!IS_LANG(arg_lang))
-    error("Internal Error: argument `arg_lang` must be language.");  // nocov
-
   SEXP lang_parsed = PROTECT(VALC_parse(lang, arg_lang, set, arg_tag));
   struct VALC_res_list res_list, res_init = VALC_res_list_init(set);
   PROTECT(res_init.list_sxp);
